@@ -7,6 +7,7 @@ from collections import namedtuple
 from enum import Enum
 from math import isfinite
 from NeuroLocoMiddleware.SoftRealtimeLoop import SoftRealtimeLoop
+from NeuroLocoMiddleware.SysID import Chirp
 import numpy as np
 import warnings
 
@@ -35,7 +36,7 @@ class TMotorManager():
     used in the context of a with as block, in order to safely enter/exit
     control of the motor.
     """
-    def __init__(self, motor_type='AK80-9', motor_ID=1, CSV_file=None, log_vars = LOG_VARIABLES):
+    def __init__(self, motor_type='AK80-9', motor_ID=1, CSV_file=None, log_vars = LOG_VARIABLES, use_torque_compensation=False):
         """
         Sets up the motor manager. Note the device will not be powered on by this method! You must
         call __enter__, mostly commonly by using a with block, before attempting to control the motor.
@@ -56,6 +57,7 @@ class TMotorManager():
                     "motor_acceleration", 
                     "motor_torque"
                 ]
+            use_torque_compensation: Enables a more complex torque model to compensate for friction, if available
         """
         self.type = motor_type
         self.ID = motor_ID
@@ -75,6 +77,9 @@ class TMotorManager():
         self._last_update_time = self._start_time
         self._last_command_time = None
         self._updated = False
+        self.use_torque_compensation = use_torque_compensation
+        self.SF = 1.0
+        self.extra_plots = []
         
         self.log_vars = log_vars
         self.LOG_FUNCTIONS = {
@@ -181,7 +186,7 @@ class TMotorManager():
 
         # writing to log file
         if self.csv_file_name is not None:
-            self.csv_writer.writerow([self._last_update_time - self._start_time] + [self.LOG_FUNCTIONS[var]() for var in self.log_vars])
+            self.csv_writer.writerow([self._last_update_time - self._start_time] + [self.LOG_FUNCTIONS[var]() for var in self.log_vars] + [data for data in self.extra_plots])
 
         self._updated = False
         
@@ -255,13 +260,14 @@ class TMotorManager():
         Returns:
             the most recently updated output torque in Nm
         """
-        if MIT_Params[self.type]['Use_derived_torque_constants']:
+        if MIT_Params[self.type]['Use_derived_torque_constants'] and self.use_torque_compensation:
             a_hat = MIT_Params[self.type]['a_hat']
             kt = MIT_Params[self.type]["NM_PER_AMP"]
             gr = MIT_Params[self.type]["GEAR_RATIO"]
             ϵ = 1.0
             i = self.get_current_qaxis_amps()
             v = self.get_motor_velocity_radians_per_second()
+
             return a_hat[0] + a_hat[1]*gr*kt*i - a_hat[2]*gr*np.abs(i)*i - a_hat[3]*np.sign(v)*(np.abs(v)/(ϵ + np.abs(v)) ) - a_hat[4]*np.abs(i)*np.sign(v)*(np.abs(v)/(ϵ + np.abs(v)) )
         else:
             return self.get_current_qaxis_amps()*MIT_Params[self.type]["NM_PER_AMP"]*MIT_Params[self.type]["GEAR_RATIO"]
@@ -358,16 +364,17 @@ class TMotorManager():
         Args:
             torque: The desired output torque in Nm.
         """
-        if MIT_Params[self.type]['Use_derived_torque_constants']:
-            self.set_motor_current_qaxis_amps((torque/MIT_Params[self.type]["NM_PER_AMP"]/MIT_Params[self.type]["GEAR_RATIO"]) )
+        if MIT_Params[self.type]['Use_derived_torque_constants'] and self.use_torque_compensation:
             a_hat = MIT_Params[self.type]['a_hat']
             kt = MIT_Params[self.type]["NM_PER_AMP"]
             gr = MIT_Params[self.type]["GEAR_RATIO"]
             ϵ = 1.0
             i = self.get_current_qaxis_amps()
             v = self.get_motor_velocity_radians_per_second()
-            SF = 0.8
-            Iq_des = (torque - a_hat[0] + np.sign(v)*(np.abs(v)/(ϵ + np.abs(v)) )*(a_hat[3] + a_hat[4]*np.abs(i))*SF )/(gr*(a_hat[1]*kt - a_hat[2]*np.abs(i)))
+            bias = - a_hat[0]
+            friction = self.SF*(v/(ϵ + np.abs(v)) )*(a_hat[3] + a_hat[4]*np.abs(i)) 
+            torque_constant = (gr*(a_hat[1]*kt - a_hat[2]*np.abs(i)))
+            Iq_des = (torque - bias + friction )/torque_constant
             self.set_motor_current_qaxis_amps(Iq_des)
         else:
             self.set_motor_current_qaxis_amps((torque/MIT_Params[self.type]["NM_PER_AMP"]/MIT_Params[self.type]["GEAR_RATIO"]) )
@@ -425,7 +432,7 @@ class TMotorManager():
         Returns:
             The most recently updated motor-side torque in Nm.
         """
-        return self.get_motor_torque_newton_meters()*MIT_Params[self.type]["GEAR_RATIO"]
+        return self.get_output_torque_newton_meters()*MIT_Params[self.type]["GEAR_RATIO"]
 
     # Pretty stuff
     def __str__(self):
@@ -480,44 +487,6 @@ class TMotorManager():
     ϕd = property (get_motor_velocity_radians_per_second, doc="motor_velocity_radians_per_second")
     ϕdd = property(get_motor_acceleration_radians_per_second_squared, doc="motor_acceleration_radians_per_second_squared")
     τm = property(get_motor_torque_newton_meters, set_motor_torque_newton_meters, doc="motor_torque_newton_meters")
-    
-
-# A sample program--should do nothing, then oscillate, then oscillate wider
-if __name__ == "__main__":
-    # use the with block to safely shut down
-    with TMotorManager(motor_type='AK80-9', motor_ID=3, CSV_file="log.csv") as dev:
-        # zero the position
-        dev.zero_position()
-
-        # wait to ensure the motor is zeroed before sending commands
-        time.sleep(1.2)
-
-        # set the gains for our controller, enter impedance only mode
-        dev.set_impedance_gains_real_unit(K=10,B=0.5)
-        
-        # Create a chirp sound to use
-        chirp = Chirp(250, 25, 1)
-
-        # create a soft realtime loop to ensure steady timing
-        loop = SoftRealtimeLoop(dt = 0.001, report=True, fade=0)
-        for t in loop:
-            # update motor state and send the current command (idle to start)
-            dev.update()
-            
-            if t < 3:
-                dev.τ = loop.fade*1.0*chirp.next(t)*3/3.7
-
-        # ensure the loop's destructor is called explicitly to show timing data
-        del loop
-
-        # store can manager for explicit destruction, not usually needed, since the CAN port
-        # will shut down when the Raspberry Pi does anyway.
-        canman = dev._canman
-
-    # shut down the CAN port
-    del canman
-
-        
 
 
         
