@@ -1,17 +1,17 @@
 from sys import path
 path.append("/home/pi/TMotorCANControl/src")
 from TMotorCANControl.TMotorManager import TMotorManager
-from SoftRealtimeLoop import SoftRealtimeLoop
-from AdcManager import ADC_Manager
+from NeuroLocoMiddleware.SoftRealtimeLoop import SoftRealtimeLoop
+from NeuroLocoMiddleware.AdcManager import ADC_Manager
 import csv
 
 
 bias = 0.5896742308538513 # Nm
 delay = 5.0 # s
-test_torques = [0.0, 0.25, -0.25, 1.0, -1.0] # Nm
+test_torques = [0.0, 0.25,-0.25, 1.0,-1.0,5.0,-5.0,10.0,-10.0] # Nm
 torque = test_torques[0] # Nm
 
-csv_file_name = "log_adc_and_motor.csv"
+csv_file_name = "log_adc_and_motor_3V.csv"
 with ADC_Manager(csv_file_name="dummyLog") as adc:
     with TMotorManager(motor_ID=3,CSV_file=None) as dev:
         with open(csv_file_name,'w') as fd:
