@@ -1,10 +1,14 @@
-from SoftRealtimeLoop import SoftRealtimeLoop
-from TMotorCANControl.TMotorManager import TMotorManager
+from NeuroLocoMiddleware.SoftRealtimeLoop import SoftRealtimeLoop
+try:
+     from TMotorCANControl.TMotorManager import TMotorManager
+except ModuleNotFoundError:
+    from sys import path
+    path.append("/home/pi/TMotorCANControl/src")
+    from TMotorCANControl.TMotorManager import TMotorManager
 import numpy as np
 import time
 
 with TMotorManager(motor_type='AK80-9', motor_ID=3, CSV_file="log.csv") as dev:
-    print(dev)
     dev.zero_position() # has a delay!
     time.sleep(1.5)
     dev.set_impedance_gains_real_unit(K=10,B=0.5)
