@@ -1,7 +1,12 @@
-from sys import path
-path.append("/home/pi/TMotorCANControl/src")
-from SoftRealtimeLoop import SoftRealtimeLoop
-from TMotorCANControl.TMotorManager import TMotorManager
+try:
+     from TMotorCANControl.TMotorManager import TMotorManager
+except ModuleNotFoundError:
+    from sys import path
+    path.append("/home/pi/TMotorCANControl/src")
+    from TMotorCANControl.TMotorManager import TMotorManager
+    
+from NeuroLocoMiddleware.SoftRealtimeLoop import SoftRealtimeLoop
+
 import time
 
 
@@ -16,6 +21,6 @@ with TMotorManager(motor_type='AK80-9', motor_ID=3, CSV_file="log.csv") as dev:
         if t < 1.0:
             dev.τ = 0.0
         else:
-            dev.τ = 0.0
+            dev.τ = 1.0
 
     del loop
\ No newline at end of file
